Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(12)

Unified Diff: trunk/src/chrome/browser/history/expire_history_backend.h

Issue 19637009: Revert 212459 "Remove TextDatabase from the history service." (Closed) Base URL: svn://svn.chromium.org/chrome/
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: trunk/src/chrome/browser/history/expire_history_backend.h
===================================================================
--- trunk/src/chrome/browser/history/expire_history_backend.h (revision 212472)
+++ trunk/src/chrome/browser/history/expire_history_backend.h (working copy)
@@ -25,6 +25,7 @@
class ArchivedDatabase;
class HistoryDatabase;
struct HistoryDetails;
+class TextDatabaseManager;
class ThumbnailDatabase;
// Delegate used to broadcast notifications to the main thread.
@@ -75,7 +76,8 @@
// Completes initialization by setting the databases that this class will use.
void SetDatabases(HistoryDatabase* main_db,
ArchivedDatabase* archived_db,
- ThumbnailDatabase* thumb_db);
+ ThumbnailDatabase* thumb_db,
+ TextDatabaseManager* text_db);
// Begins periodic expiration of history older than the given threshold. This
// will continue until the object is deleted.
@@ -126,6 +128,9 @@
// Deletes the visit-related stuff for all the visits in the given list, and
// adds the rows for unique URLs affected to the affected_urls list in
// the dependencies structure.
+ //
+ // Deleted information is the visits themselves and the full-text index
+ // entries corresponding to them.
void DeleteVisitRelatedInfo(const VisitVector& visits,
DeleteDependencies* dependencies);
@@ -133,7 +138,8 @@
void ArchiveVisits(const VisitVector& visits);
// Finds or deletes dependency information for the given URL. Information that
// is specific to this URL (URL row, thumbnails, etc.) is deleted.
//
// This does not affect the visits! This is used for expiration as well as
// deleting from the UI, and they handle visits differently.
@@ -234,6 +240,12 @@
// and deletes items. For example, URLs with no visits.
void ParanoidExpireHistory();
+ // Schedules a call to DoExpireHistoryIndexFiles.
+ void ScheduleExpireHistoryIndexFiles();
+
+ // Deletes old history index files.
+ void DoExpireHistoryIndexFiles();
+
// Returns the BookmarkService, blocking until it is loaded. This may return
// NULL.
BookmarkService* GetBookmarkService();
@@ -257,6 +269,7 @@
HistoryDatabase* main_db_; // Main history database.
ArchivedDatabase* archived_db_; // Old history.
ThumbnailDatabase* thumb_db_; // Thumbnails and favicons.
+ TextDatabaseManager* text_db_; // Full text index.
// Used to generate runnable methods to do timers on this class. They will be
// automatically canceled when this class is deleted.
@@ -133,7 +138,8 @@
void ArchiveVisits(const VisitVector& visits);
// Finds or deletes dependency information for the given URL. Information that
- // is specific to this URL (URL row, thumbnails, etc.) is deleted.
+ // is specific to this URL (URL row, thumbnails, full text indexed stuff,
+ // etc.) is deleted.
//
// This does not affect the visits! This is used for expiration as well as

Powered by Google App Engine
This is Rietveld 408576698